@@ -114,7 +114,7 @@ class Adapter:  # pylint: disable=too-many-instance-attributes
                     )
                     # Succeeded.
                     self._hcitool_is_usable = True
-                except subprocess.SubprocessError:
+                except (subprocess.SubprocessError, FileNotFoundError, PermissionError):
                     # Lots of things can go wrong:
                     # no hcitool, no privileges (causes non-zero return code), too slow, etc.
                     pass
@@ -175,6 +175,8 @@ class Adapter:  # pylint: disable=too-many-instance-attributes
         *,
         scan_response: Buf = None,
         connectable: bool = True,
+        anonymous: bool = False,
+        timeout: int = 0,
         interval: float = 0.1,
     ) -> None:
         raise NotImplementedError("Advertising not implemented")
